@@ -55,3 +55,30 @@ test_that("output matches", {
   expect_equal( lo[1, 5],  66.75361799, tolerance = .002 )
   expect_equal( lo[81, 5], 96.78316785, tolerance = .002 )
 })
+
+
+context("leontief-finalDemand")
+
+# leontief decomposition
+lfd <- decomp(inter,
+             final,
+             countries,
+             industries,
+             out,
+             method = "leontief",
+             post = "final_demand")
+
+test_that("output size matches", {
+  expect_equal( length(lfd), 4)
+  expect_equal( dim(lfd)[1], 27)
+})
+
+test_that("output format matches", {
+  expect_match(typeof(lfd[, 4]), "double")
+})
+
+# test output content (i.e. numbers)
+test_that("output matches", {
+  expect_equal(lfd[1, 4], 24.3345824, tolerance = .002)
+  expect_equal(lfd[20, 4], 23.6841309, tolerance = .002)
+})
